@@ -140,9 +140,17 @@ class K8SDeploy(Deploy):
         if "affinity" in kw and kw["affinity"] is not None:
             deploy_info["spec"]["template"]["spec"]["affinity"] = kw["affinity"]
 
+        if "nodeSelector" in kw and kw["nodeSelector"] is not None:
+            deploy_info["spec"]["template"]["spec"]["nodeSelector"] = kw["nodeSelector"]
+
         if "tolerations" in kw and kw["tolerations"] is not None:
             deploy_info["spec"]["template"]["spec"]["tolerations"] = kw["tolerations"]
 
+        if "securityContext" in kw and kw["securityContext"] is not None:
+            deploy_info["spec"]["template"]["spec"]["containers"][0]["securityContext"] = kw[
+                "securityContext"
+            ]
+
         return deploy_info
 
     def get_payload(self):
